@@ -10,6 +10,8 @@ MIDDLEWARE_FACTORY_TRACE_ENV: str = "POWERTOOLS_TRACE_MIDDLEWARES"
 
 METRICS_NAMESPACE_ENV: str = "POWERTOOLS_METRICS_NAMESPACE"
 
+DATADOG_FLUSH_TO_LOG: str = "DD_FLUSH_TO_LOG"
+
 SERVICE_NAME_ENV: str = "POWERTOOLS_SERVICE_NAME"
 XRAY_TRACE_ID_ENV: str = "_X_AMZN_TRACE_ID"
 LAMBDA_TASK_ROOT_ENV: str = "LAMBDA_TASK_ROOT"
@@ -40,3 +42,18 @@ COMPACT_INDENT = None
 
 POWERTOOLS_DEV_ENV: str = "POWERTOOLS_DEV"
 POWERTOOLS_DEBUG_ENV: str = "POWERTOOLS_DEBUG"
+POWERTOOLS_LOG_LEVEL_ENV: str = "POWERTOOLS_LOG_LEVEL"
+POWERTOOLS_LOG_LEVEL_LEGACY_ENV: str = "LOG_LEVEL"
+LAMBDA_LOG_LEVEL_ENV: str = "AWS_LAMBDA_LOG_LEVEL"
+
+# Mapping of Lambda log levels to Python logging levels
+# https://docs.aws.amazon.com/lambda/latest/dg/configuration-logging.html#configuration-logging-log-levels
+LAMBDA_ADVANCED_LOGGING_LEVELS = {
+    None: None,
+    "TRACE": "NOTSET",
+    "DEBUG": "DEBUG",
+    "INFO": "INFO",
+    "WARN": "WARNING",
+    "ERROR": "ERROR",
+    "FATAL": "CRITICAL",
+}
