@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import base64
-import dataclasses
 import itertools
 import logging
 import os
@@ -72,7 +71,8 @@ def resolve_env_var_choice(env: Optional[str], choice: Optional[str]) -> str:
 
 
 def resolve_env_var_choice(
-    env: Optional[str] = None, choice: Optional[Union[str, float]] = None
+    env: Optional[str] = None,
+    choice: Optional[Union[str, float]] = None,
 ) -> Optional[Union[str, float]]:
     """Pick explicit choice over env, if available, otherwise return env value received
 
@@ -112,7 +112,8 @@ def powertools_dev_is_set() -> bool:
     is_on = strtobool(os.getenv(constants.POWERTOOLS_DEV_ENV, "0"))
     if is_on:
         warnings.warn(
-            "POWERTOOLS_DEV environment variable is enabled. Increasing verbosity across utilities.", stacklevel=2
+            "POWERTOOLS_DEV environment variable is enabled. Increasing verbosity across utilities.",
+            stacklevel=2,
         )
         return True
 
@@ -166,8 +167,86 @@ def extract_event_from_common_models(data: Any) -> Dict | Any:
         return data.raw_event
 
     # Is it a Pydantic Model?
-    if callable(getattr(data, "dict", None)):
-        return data.dict()
+    if is_pydantic(data):
+        return pydantic_to_dict(data)
 
-    # Is it a Dataclass? If not return as is
-    return dataclasses.asdict(data) if dataclasses.is_dataclass(data) else data
+    # Is it a Dataclass?
+    if is_dataclass(data):
+        return dataclass_to_dict(data)
+
+    # Return as is
+    return data
+
+
+def is_pydantic(data) -> bool:
+    """Whether data is a Pydantic model by checking common field available in v1/v2
+
+    Parameters
+    ----------
+    data: BaseModel
+        Pydantic model
+
+    Returns
+    -------
+    bool
+        Whether it's a Pydantic model
+    """
+    return getattr(data, "json", False)
+
+
+def is_dataclass(data) -> bool:
+    """Whether data is a dataclass
+
+    Parameters
+    ----------
+    data: dataclass
+        Dataclass obj
+
+    Returns
+    -------
+    bool
+        Whether it's a Dataclass
+    """
+    return getattr(data, "__dataclass_fields__", False)
+
+
+def pydantic_to_dict(data) -> dict:
+    """Dump Pydantic model v1 and v2 as dict.
+
+    Note we use lazy import since Pydantic is an optional dependency.
+
+    Parameters
+    ----------
+    data: BaseModel
+        Pydantic model
+
+    Returns
+    -------
+
+    dict:
+        Pydantic model serialized to dict
+    """
+    from aws_lambda_powertools.event_handler.openapi.compat import _model_dump
+
+    return _model_dump(data)
+
+
+def dataclass_to_dict(data) -> dict:
+    """Dump standard dataclass as dict.
+
+    Note we use lazy import to prevent bloating other code parts.
+
+    Parameters
+    ----------
+    data: dataclass
+        Dataclass
+
+    Returns
+    -------
+
+    dict:
+        Pydantic model serialized to dict
+    """
+    import dataclasses
+
+    return dataclasses.asdict(data)
