@@ -1,6 +1,8 @@
 """
 Batch processing exceptions
 """
+from __future__ import annotations
+
 import traceback
 from types import TracebackType
 from typing import List, Optional, Tuple, Type
@@ -9,10 +11,10 @@ ExceptionInfo = Tuple[Optional[Type[BaseException]], Optional[BaseException], Op
 
 
 class BaseBatchProcessingError(Exception):
-    def __init__(self, msg="", child_exceptions: Optional[List[ExceptionInfo]] = None):
+    def __init__(self, msg="", child_exceptions: List[ExceptionInfo] | None = None):
         super().__init__(msg)
         self.msg = msg
-        self.child_exceptions = child_exceptions
+        self.child_exceptions = child_exceptions or []
 
     def format_exceptions(self, parent_exception_str):
         exception_list = [f"{parent_exception_str}\n"]
@@ -27,7 +29,7 @@ class BaseBatchProcessingError(Exception):
 class BatchProcessingError(BaseBatchProcessingError):
     """When all batch records failed to be processed"""
 
-    def __init__(self, msg="", child_exceptions: Optional[List[ExceptionInfo]] = None):
+    def __init__(self, msg="", child_exceptions: List[ExceptionInfo] | None = None):
         super().__init__(msg, child_exceptions)
 
     def __str__(self):
