@@ -2,8 +2,12 @@
 Utility for adding idempotency to lambda functions
 """
 
-from aws_lambda_powertools.utilities.idempotency.persistence.base import BasePersistenceLayer
-from aws_lambda_powertools.utilities.idempotency.persistence.dynamodb import DynamoDBPersistenceLayer
+from aws_lambda_powertools.utilities.idempotency.persistence.base import (
+    BasePersistenceLayer,
+)
+from aws_lambda_powertools.utilities.idempotency.persistence.dynamodb import (
+    DynamoDBPersistenceLayer,
+)
 
 from .idempotency import IdempotencyConfig, idempotent, idempotent_function
 
