@@ -18,6 +18,12 @@ from aws_lambda_powertools.utilities.idempotency.persistence.base import (
     BasePersistenceLayer,
     DataRecord,
 )
+from aws_lambda_powertools.utilities.idempotency.serialization.base import (
+    BaseIdempotencySerializer,
+)
+from aws_lambda_powertools.utilities.idempotency.serialization.no_op import (
+    NoOpSerializer,
+)
 
 MAX_RETRIES = 2
 logger = logging.getLogger(__name__)
@@ -51,6 +57,7 @@ class IdempotencyHandler:
         function_payload: Any,
         config: IdempotencyConfig,
         persistence_store: BasePersistenceLayer,
+        output_serializer: Optional[BaseIdempotencySerializer] = None,
         function_args: Optional[Tuple] = None,
         function_kwargs: Optional[Dict] = None,
     ):
@@ -65,12 +72,16 @@ class IdempotencyHandler:
             Idempotency Configuration
         persistence_store : BasePersistenceLayer
             Instance of persistence layer to store idempotency records
+        output_serializer: Optional[BaseIdempotencySerializer]
+            Serializer to transform the data to and from a dictionary.
+            If not supplied, no serialization is done via the NoOpSerializer
         function_args: Optional[Tuple]
             Function arguments
         function_kwargs: Optional[Dict]
             Function keyword arguments
         """
         self.function = function
+        self.output_serializer = output_serializer or NoOpSerializer()
         self.data = deepcopy(_prepare_data(function_payload))
         self.fn_args = function_args
         self.fn_kwargs = function_kwargs
@@ -104,17 +115,20 @@ class IdempotencyHandler:
             # We call save_inprogress first as an optimization for the most common case where no idempotent record
             # already exists. If it succeeds, there's no need to call get_record.
             self.persistence_store.save_inprogress(
-                data=self.data, remaining_time_in_millis=self._get_remaining_time_in_millis()
+                data=self.data,
+                remaining_time_in_millis=self._get_remaining_time_in_millis(),
             )
         except IdempotencyKeyError:
             raise
         except IdempotencyItemAlreadyExistsError:
             # Now we know the item already exists, we can retrieve it
             record = self._get_idempotency_record()
-            return self._handle_for_status(record)
+            if record is not None:
+                return self._handle_for_status(record)
         except Exception as exc:
             raise IdempotencyPersistenceLayerError(
-                "Failed to save in progress record to idempotency store", exc
+                "Failed to save in progress record to idempotency store",
+                exc,
             ) from exc
 
         return self._get_function_response()
@@ -138,7 +152,7 @@ class IdempotencyHandler:
 
         return None
 
-    def _get_idempotency_record(self) -> DataRecord:
+    def _get_idempotency_record(self) -> Optional[DataRecord]:
         """
         Retrieve the idempotency record from the persistence layer.
 
@@ -152,7 +166,7 @@ class IdempotencyHandler:
         except IdempotencyItemNotFoundError:
             # This code path will only be triggered if the record is removed between save_inprogress and get_record.
             logger.debug(
-                f"An existing idempotency record was deleted before we could fetch it. Proceeding with {self.function}"
+                f"An existing idempotency record was deleted before we could fetch it. Proceeding with {self.function}",
             )
             raise IdempotencyInconsistentStateError("save_inprogress and get_record return inconsistent results.")
 
@@ -167,7 +181,7 @@ class IdempotencyHandler:
 
         return data_record
 
-    def _handle_for_status(self, data_record: DataRecord) -> Optional[Dict[Any, Any]]:
+    def _handle_for_status(self, data_record: DataRecord) -> Optional[Any]:
         """
         Take appropriate action based on data_record's status
 
@@ -177,8 +191,9 @@ class IdempotencyHandler:
 
         Returns
         -------
-        Optional[Dict[Any, Any]
+        Optional[Any]
             Function's response previously used for this idempotency key, if it has successfully executed already.
+            In case an output serializer is configured, the response is deserialized.
 
         Raises
         ------
@@ -193,18 +208,20 @@ class IdempotencyHandler:
 
         if data_record.status == STATUS_CONSTANTS["INPROGRESS"]:
             if data_record.in_progress_expiry_timestamp is not None and data_record.in_progress_expiry_timestamp < int(
-                datetime.datetime.now().timestamp() * 1000
+                datetime.datetime.now().timestamp() * 1000,
             ):
                 raise IdempotencyInconsistentStateError(
-                    "item should have been expired in-progress because it already time-outed."
+                    "item should have been expired in-progress because it already time-outed.",
                 )
 
             raise IdempotencyAlreadyInProgressError(
                 f"Execution already in progress with idempotency key: "
-                f"{self.persistence_store.event_key_jmespath}={data_record.idempotency_key}"
+                f"{self.persistence_store.event_key_jmespath}={data_record.idempotency_key}",
             )
-
-        return data_record.response_json_as_dict()
+        response_dict: Optional[dict] = data_record.response_json_as_dict()
+        if response_dict is not None:
+            return self.output_serializer.from_dict(response_dict)
+        return None
 
     def _get_function_response(self):
         try:
@@ -216,16 +233,19 @@ class IdempotencyHandler:
                 self.persistence_store.delete_record(data=self.data, exception=handler_exception)
             except Exception as delete_exception:
                 raise IdempotencyPersistenceLayerError(
-                    "Failed to delete record from idempotency store", delete_exception
+                    "Failed to delete record from idempotency store",
+                    delete_exception,
                 ) from delete_exception
             raise
 
         else:
             try:
-                self.persistence_store.save_success(data=self.data, result=response)
+                serialized_response: dict = self.output_serializer.to_dict(response) if response else None
+                self.persistence_store.save_success(data=self.data, result=serialized_response)
             except Exception as save_exception:
                 raise IdempotencyPersistenceLayerError(
-                    "Failed to update record state to success in idempotency store", save_exception
+                    "Failed to update record state to success in idempotency store",
+                    save_exception,
                 ) from save_exception
 
         return response
