@@ -163,7 +163,9 @@ class DynamoDBPersistenceLayer(BasePersistenceLayer):
 
     def _get_record(self, idempotency_key) -> DataRecord:
         response = self.client.get_item(
-            TableName=self.table_name, Key=self._get_key(idempotency_key), ConsistentRead=True
+            TableName=self.table_name,
+            Key=self._get_key(idempotency_key),
+            ConsistentRead=True,
         )
         try:
             item = response["Item"]
@@ -211,7 +213,7 @@ class DynamoDBPersistenceLayer(BasePersistenceLayer):
                     "#status = :inprogress",
                     "attribute_exists(#in_progress_expiry)",
                     "#in_progress_expiry < :now_in_millis",
-                ]
+                ],
             )
 
             condition_expression = (
@@ -237,7 +239,7 @@ class DynamoDBPersistenceLayer(BasePersistenceLayer):
             error_code = exc.response.get("Error", {}).get("Code")
             if error_code == "ConditionalCheckFailedException":
                 logger.debug(
-                    f"Failed to put record for already existing idempotency key: {data_record.idempotency_key}"
+                    f"Failed to put record for already existing idempotency key: {data_record.idempotency_key}",
                 )
                 raise IdempotencyItemAlreadyExistsError from exc
             else:
@@ -245,7 +247,7 @@ class DynamoDBPersistenceLayer(BasePersistenceLayer):
 
     def _update_record(self, data_record: DataRecord):
         logger.debug(f"Updating record for idempotency key: {data_record.idempotency_key}")
-        update_expression = "SET #response_data = :response_data, #expiry = :expiry, " "#status = :status"
+        update_expression = "SET #response_data = :response_data, #expiry = :expiry, #status = :status"
         expression_attr_values: Dict[str, "AttributeValueTypeDef"] = {
             ":expiry": {"N": str(data_record.expiry_timestamp)},
             ":response_data": {"S": data_record.response_data},
