@@ -8,7 +8,6 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union, overl
 
 import boto3
 from botocore.config import Config
-from typing_extensions import Literal
 
 from aws_lambda_powertools.shared import constants
 from aws_lambda_powertools.shared.functions import (
@@ -16,6 +15,7 @@ from aws_lambda_powertools.shared.functions import (
     resolve_truthy_env_var_choice,
     slice_dictionary,
 )
+from aws_lambda_powertools.shared.types import Literal
 
 from .base import DEFAULT_MAX_AGE_SECS, DEFAULT_PROVIDERS, BaseProvider, transform_value
 from .exceptions import GetParameterError
@@ -108,7 +108,10 @@ class SSMProvider(BaseProvider):
         super().__init__()
 
         self.client: "SSMClient" = self._build_boto3_client(
-            service_name="ssm", client=boto3_client, session=boto3_session, config=config
+            service_name="ssm",
+            client=boto3_client,
+            session=boto3_session,
+            config=config,
         )
 
     # We break Liskov substitution principle due to differences in signatures of this method and superclass get method
@@ -156,7 +159,8 @@ class SSMProvider(BaseProvider):
 
         # If decrypt is not set, resolve it from the environment variable, defaulting to False
         decrypt = resolve_truthy_env_var_choice(
-            env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"), choice=decrypt
+            env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"),
+            choice=decrypt,
         )
 
         # Add to `decrypt` sdk_options to we can have an explicit option for this
@@ -184,7 +188,13 @@ class SSMProvider(BaseProvider):
 
         return self.client.get_parameter(**sdk_options)["Parameter"]["Value"]
 
-    def _get_multiple(self, path: str, decrypt: bool = False, recursive: bool = False, **sdk_options) -> Dict[str, str]:
+    def _get_multiple(
+        self,
+        path: str,
+        decrypt: Optional[bool] = None,
+        recursive: bool = False,
+        **sdk_options,
+    ) -> Dict[str, str]:
         """
         Retrieve multiple parameter values from AWS Systems Manager Parameter Store
 
@@ -200,6 +210,12 @@ class SSMProvider(BaseProvider):
             Dictionary of options that will be passed to the Parameter Store get_parameters_by_path API call
         """
 
+        # If decrypt is not set, resolve it from the environment variable, defaulting to False
+        decrypt = resolve_truthy_env_var_choice(
+            env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"),
+            choice=decrypt,
+        )
+
         # Explicit arguments will take precedence over keyword arguments
         sdk_options["Path"] = path
         sdk_options["WithDecryption"] = decrypt
@@ -279,7 +295,8 @@ class SSMProvider(BaseProvider):
 
         # If decrypt is not set, resolve it from the environment variable, defaulting to False
         decrypt = resolve_truthy_env_var_choice(
-            env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"), choice=decrypt
+            env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"),
+            choice=decrypt,
         )
 
         # Init potential batch/decrypt batch responses and errors
@@ -313,13 +330,15 @@ class SSMProvider(BaseProvider):
         return {**response, **batch_ret, **decrypt_ret}
 
     def _get_parameters_by_name_with_decrypt_option(
-        self, batch: Dict[str, Dict], raise_on_error: bool
+        self,
+        batch: Dict[str, Dict],
+        raise_on_error: bool,
     ) -> Tuple[Dict, List]:
         response: Dict[str, Any] = {}
         errors: List[str] = []
 
         # Decided for single-thread as it outperforms in 128M and 1G + reduce timeout risk
-        # see: https://github.com/awslabs/aws-lambda-powertools-python/issues/1040#issuecomment-1299954613
+        # see: https://github.com/aws-powertools/powertools-lambda-python/issues/1040#issuecomment-1299954613
         for parameter, options in batch.items():
             try:
                 response[parameter] = self.get(parameter, options["max_age"], options["transform"], options["decrypt"])
@@ -332,7 +351,10 @@ class SSMProvider(BaseProvider):
         return response, errors
 
     def _get_parameters_batch_by_name(
-        self, batch: Dict[str, Dict], raise_on_error: bool = True, decrypt: bool = False
+        self,
+        batch: Dict[str, Dict],
+        raise_on_error: bool = True,
+        decrypt: bool = False,
     ) -> Tuple[Dict, List]:
         """Slice batch and fetch parameters using GetParameters by max permitted"""
         errors: List[str] = []
@@ -358,7 +380,11 @@ class SSMProvider(BaseProvider):
         return cache
 
     def _get_parameters_by_name_in_chunks(
-        self, batch: Dict[str, Dict], cache: Dict[str, Any], raise_on_error: bool, decrypt: bool = False
+        self,
+        batch: Dict[str, Dict],
+        cache: Dict[str, Any],
+        raise_on_error: bool,
+        decrypt: bool = False,
     ) -> Tuple[Dict, List]:
         """Take out differences from cache and batch, slice it and fetch from SSM"""
         response: Dict[str, Any] = {}
@@ -368,7 +394,9 @@ class SSMProvider(BaseProvider):
 
         for chunk in slice_dictionary(data=diff, chunk_size=self._MAX_GET_PARAMETERS_ITEM):
             response, possible_errors = self._get_parameters_by_name(
-                parameters=chunk, raise_on_error=raise_on_error, decrypt=decrypt
+                parameters=chunk,
+                raise_on_error=raise_on_error,
+                decrypt=decrypt,
             )
             response.update(response)
             errors.extend(possible_errors)
@@ -376,7 +404,10 @@ class SSMProvider(BaseProvider):
         return response, errors
 
     def _get_parameters_by_name(
-        self, parameters: Dict[str, Dict], raise_on_error: bool = True, decrypt: bool = False
+        self,
+        parameters: Dict[str, Dict],
+        raise_on_error: bool = True,
+        decrypt: bool = False,
     ) -> Tuple[Dict[str, Any], List[str]]:
         """Use SSM GetParameters to fetch parameters, hydrate cache, and handle partial failure
 
@@ -418,7 +449,10 @@ class SSMProvider(BaseProvider):
         return transformed_params, batch_errors
 
     def _transform_and_cache_get_parameters_response(
-        self, api_response: GetParametersResultTypeDef, parameters: Dict[str, Any], raise_on_error: bool = True
+        self,
+        api_response: GetParametersResultTypeDef,
+        parameters: Dict[str, Any],
+        raise_on_error: bool = True,
     ) -> Dict[str, Any]:
         response: Dict[str, Any] = {}
 
@@ -441,7 +475,8 @@ class SSMProvider(BaseProvider):
 
     @staticmethod
     def _handle_any_invalid_get_parameter_errors(
-        api_response: GetParametersResultTypeDef, raise_on_error: bool = True
+        api_response: GetParametersResultTypeDef,
+        raise_on_error: bool = True,
     ) -> List[str]:
         """GetParameters is non-atomic. Failures don't always reflect in exceptions so we need to collect."""
         failed_parameters = api_response["InvalidParameters"]
@@ -455,7 +490,10 @@ class SSMProvider(BaseProvider):
 
     @staticmethod
     def _split_batch_and_decrypt_parameters(
-        parameters: Dict[str, Dict], transform: TransformOptions, max_age: int, decrypt: bool
+        parameters: Dict[str, Dict],
+        transform: TransformOptions,
+        max_age: int,
+        decrypt: bool,
     ) -> Tuple[Dict[str, Dict], Dict[str, Dict]]:
         """Split parameters that can be fetched by GetParameters vs GetParameter
 
@@ -503,7 +541,7 @@ class SSMProvider(BaseProvider):
         """Raise GetParameterError if fail-fast is disabled and '_errors' key is in parameters batch"""
         if not raise_on_error and reserved_parameter in parameters:
             raise GetParameterError(
-                f"You cannot fetch a parameter named '{reserved_parameter}' in graceful error mode."
+                f"You cannot fetch a parameter named '{reserved_parameter}' in graceful error mode.",
             )
 
 
@@ -571,14 +609,19 @@ def get_parameter(
 
     # If decrypt is not set, resolve it from the environment variable, defaulting to False
     decrypt = resolve_truthy_env_var_choice(
-        env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"), choice=decrypt
+        env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"),
+        choice=decrypt,
     )
 
     # Add to `decrypt` sdk_options to we can have an explicit option for this
     sdk_options["decrypt"] = decrypt
 
     return DEFAULT_PROVIDERS["ssm"].get(
-        name, max_age=max_age, transform=transform, force_fetch=force_fetch, **sdk_options
+        name,
+        max_age=max_age,
+        transform=transform,
+        force_fetch=force_fetch,
+        **sdk_options,
     )
 
 
@@ -595,6 +638,8 @@ def get_parameters(
     """
     Retrieve multiple parameter values from AWS Systems Manager (SSM) Parameter Store
 
+    For readability, we strip the path prefix name in the response.
+
     Parameters
     ----------
     path: str
@@ -633,9 +678,8 @@ def get_parameters(
         >>>
         >>> for key, value in values.items():
         ...     print(key, value)
-        /my/path/prefix/a   Parameter value a
-        /my/path/prefix/b   Parameter value b
-        /my/path/prefix/c   Parameter value c
+        config              Parameter value (/my/path/prefix/config)
+        webhook/config      Parameter value (/my/path/prefix/webhook/config)
 
     **Retrieves parameter values and decodes them using a Base64 decoder**
 
@@ -653,7 +697,8 @@ def get_parameters(
 
     # If decrypt is not set, resolve it from the environment variable, defaulting to False
     decrypt = resolve_truthy_env_var_choice(
-        env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"), choice=decrypt
+        env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"),
+        choice=decrypt,
     )
 
     sdk_options["recursive"] = recursive
@@ -769,14 +814,15 @@ def get_parameters_by_name(
     """
 
     # NOTE: Decided against using multi-thread due to single-thread outperforming in 128M and 1G + timeout risk
-    # see: https://github.com/awslabs/aws-lambda-powertools-python/issues/1040#issuecomment-1299954613
+    # see: https://github.com/aws-powertools/powertools-lambda-python/issues/1040#issuecomment-1299954613
 
     # If max_age is not set, resolve it from the environment variable, defaulting to DEFAULT_MAX_AGE_SECS
     max_age = resolve_max_age(env=os.getenv(constants.PARAMETERS_MAX_AGE_ENV, DEFAULT_MAX_AGE_SECS), choice=max_age)
 
     # If decrypt is not set, resolve it from the environment variable, defaulting to False
     decrypt = resolve_truthy_env_var_choice(
-        env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"), choice=decrypt
+        env=os.getenv(constants.PARAMETERS_SSM_DECRYPT_ENV, "false"),
+        choice=decrypt,
     )
 
     # Only create the provider if this function is called at least once
@@ -784,5 +830,9 @@ def get_parameters_by_name(
         DEFAULT_PROVIDERS["ssm"] = SSMProvider()
 
     return DEFAULT_PROVIDERS["ssm"].get_parameters_by_name(
-        parameters=parameters, max_age=max_age, transform=transform, decrypt=decrypt, raise_on_error=raise_on_error
+        parameters=parameters,
+        max_age=max_age,
+        transform=transform,
+        decrypt=decrypt,
+        raise_on_error=raise_on_error,
     )
