@@ -1,3 +1,3 @@
-from typing_extensions import Literal
+from aws_lambda_powertools.shared.types import Literal
 
 TransformOptions = Literal["json", "binary", "auto", None]
