@@ -14,23 +14,23 @@ class RequestContextV2AuthorizerIamCognito(BaseModel):
 
 
 class RequestContextV2AuthorizerIam(BaseModel):
-    accessKey: Optional[str]
-    accountId: Optional[str]
-    callerId: Optional[str]
-    principalOrgId: Optional[str]
-    userArn: Optional[str]
-    userId: Optional[str]
-    cognitoIdentity: RequestContextV2AuthorizerIamCognito
+    accessKey: Optional[str] = None
+    accountId: Optional[str] = None
+    callerId: Optional[str] = None
+    principalOrgId: Optional[str] = None
+    userArn: Optional[str] = None
+    userId: Optional[str] = None
+    cognitoIdentity: Optional[RequestContextV2AuthorizerIamCognito] = None
 
 
 class RequestContextV2AuthorizerJwt(BaseModel):
     claims: Dict[str, Any]
-    scopes: List[str]
+    scopes: Optional[List[str]] = None
 
 
 class RequestContextV2Authorizer(BaseModel):
-    jwt: Optional[RequestContextV2AuthorizerJwt]
-    iam: Optional[RequestContextV2AuthorizerIam]
+    jwt: Optional[RequestContextV2AuthorizerJwt] = None
+    iam: Optional[RequestContextV2AuthorizerIam] = None
     lambda_value: Optional[Dict[str, Any]] = Field(None, alias="lambda")
 
 
@@ -45,7 +45,7 @@ class RequestContextV2Http(BaseModel):
 class RequestContextV2(BaseModel):
     accountId: str
     apiId: str
-    authorizer: Optional[RequestContextV2Authorizer]
+    authorizer: Optional[RequestContextV2Authorizer] = None
     domainName: str
     domainPrefix: str
     requestId: str
@@ -61,11 +61,11 @@ class APIGatewayProxyEventV2Model(BaseModel):
     routeKey: str
     rawPath: str
     rawQueryString: str
-    cookies: Optional[List[str]]
+    cookies: Optional[List[str]] = None
     headers: Dict[str, str]
-    queryStringParameters: Optional[Dict[str, str]]
-    pathParameters: Optional[Dict[str, str]]
-    stageVariables: Optional[Dict[str, str]]
+    queryStringParameters: Optional[Dict[str, str]] = None
+    pathParameters: Optional[Dict[str, str]] = None
+    stageVariables: Optional[Dict[str, str]] = None
     requestContext: RequestContextV2
-    body: Optional[Union[str, Type[BaseModel]]]
+    body: Optional[Union[str, Type[BaseModel]]] = None
     isBase64Encoded: bool
